import { z } from "zod";
export declare const TaskSchema: z.ZodObject<z.extendShape<{
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    subtype: z.ZodString;
    view: z.ZodRecord<z.ZodString, z.ZodAny>;
    evaluation: z.ZodObject<{
        mode: z.ZodEnum<["auto", "skip", "manual"]>;
        enableRetry: z.ZodBoolean;
        showFeedback: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        mode: "auto" | "skip" | "manual";
        enableRetry: boolean;
        showFeedback: boolean;
    }, {
        mode: "auto" | "skip" | "manual";
        enableRetry: boolean;
        showFeedback: boolean;
    }>;
    feedback: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
}, {
    subtype: z.ZodLiteral<"highlighting">;
    view: z.ZodObject<{
        instruction: z.ZodString;
        text: z.ZodString;
        colors: z.ZodObject<{
            maroon: z.ZodObject<{
                enabled: z.ZodBoolean;
                label: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                label?: string | undefined;
                enabled: boolean;
            }, {
                label?: string | undefined;
                enabled: boolean;
            }>;
            orange: z.ZodObject<{
                enabled: z.ZodBoolean;
                label: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                label?: string | undefined;
                enabled: boolean;
            }, {
                label?: string | undefined;
                enabled: boolean;
            }>;
            blue: z.ZodObject<{
                enabled: z.ZodBoolean;
                label: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                label?: string | undefined;
                enabled: boolean;
            }, {
                label?: string | undefined;
                enabled: boolean;
            }>;
            lavender: z.ZodObject<{
                enabled: z.ZodBoolean;
                label: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                label?: string | undefined;
                enabled: boolean;
            }, {
                label?: string | undefined;
                enabled: boolean;
            }>;
            yellow: z.ZodObject<{
                enabled: z.ZodBoolean;
                label: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                label?: string | undefined;
                enabled: boolean;
            }, {
                label?: string | undefined;
                enabled: boolean;
            }>;
        }, "strip", z.ZodTypeAny, {
            maroon: {
                label?: string | undefined;
                enabled: boolean;
            };
            orange: {
                label?: string | undefined;
                enabled: boolean;
            };
            blue: {
                label?: string | undefined;
                enabled: boolean;
            };
            lavender: {
                label?: string | undefined;
                enabled: boolean;
            };
            yellow: {
                label?: string | undefined;
                enabled: boolean;
            };
        }, {
            maroon: {
                label?: string | undefined;
                enabled: boolean;
            };
            orange: {
                label?: string | undefined;
                enabled: boolean;
            };
            blue: {
                label?: string | undefined;
                enabled: boolean;
            };
            lavender: {
                label?: string | undefined;
                enabled: boolean;
            };
            yellow: {
                label?: string | undefined;
                enabled: boolean;
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        instruction: string;
        text: string;
        colors: {
            maroon: {
                label?: string | undefined;
                enabled: boolean;
            };
            orange: {
                label?: string | undefined;
                enabled: boolean;
            };
            blue: {
                label?: string | undefined;
                enabled: boolean;
            };
            lavender: {
                label?: string | undefined;
                enabled: boolean;
            };
            yellow: {
                label?: string | undefined;
                enabled: boolean;
            };
        };
    }, {
        instruction: string;
        text: string;
        colors: {
            maroon: {
                label?: string | undefined;
                enabled: boolean;
            };
            orange: {
                label?: string | undefined;
                enabled: boolean;
            };
            blue: {
                label?: string | undefined;
                enabled: boolean;
            };
            lavender: {
                label?: string | undefined;
                enabled: boolean;
            };
            yellow: {
                label?: string | undefined;
                enabled: boolean;
            };
        };
    }>;
    evaluation: z.ZodObject<z.extendShape<{
        mode: z.ZodEnum<["auto", "skip", "manual"]>;
        enableRetry: z.ZodBoolean;
        showFeedback: z.ZodBoolean;
    }, {
        cutoffs: z.ZodObject<{
            maroon: z.ZodNumber;
            orange: z.ZodNumber;
            blue: z.ZodNumber;
            lavender: z.ZodNumber;
            yellow: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            maroon: number;
            orange: number;
            blue: number;
            lavender: number;
            yellow: number;
        }, {
            maroon: number;
            orange: number;
            blue: number;
            lavender: number;
            yellow: number;
        }>;
        highlights: z.ZodArray<z.ZodUnion<[z.ZodEnum<["maroon", "orange", "blue", "lavender", "yellow"]>, z.ZodNull]>, "many">;
    }>, "strip", z.ZodTypeAny, {
        mode: "auto" | "skip" | "manual";
        enableRetry: boolean;
        showFeedback: boolean;
        cutoffs: {
            maroon: number;
            orange: number;
            blue: number;
            lavender: number;
            yellow: number;
        };
        highlights: ("maroon" | "orange" | "blue" | "lavender" | "yellow" | null)[];
    }, {
        mode: "auto" | "skip" | "manual";
        enableRetry: boolean;
        showFeedback: boolean;
        cutoffs: {
            maroon: number;
            orange: number;
            blue: number;
            lavender: number;
            yellow: number;
        };
        highlights: ("maroon" | "orange" | "blue" | "lavender" | "yellow" | null)[];
    }>;
    feedback: z.ZodObject<{
        highlightAgreement: z.ZodBoolean;
        agreement: z.ZodOptional<z.ZodArray<z.ZodObject<{
            color: z.ZodEnum<["maroon", "orange", "blue", "lavender", "yellow"]>;
            threshold: z.ZodNumber;
            feedback: z.ZodObject<{
                message: z.ZodString;
                severity: z.ZodEnum<["error", "warning", "info", "success"]>;
            }, "strip", z.ZodTypeAny, {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            }, {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            }>;
        }, "strip", z.ZodTypeAny, {
            feedback: {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            };
            color: "maroon" | "orange" | "blue" | "lavender" | "yellow";
            threshold: number;
        }, {
            feedback: {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            };
            color: "maroon" | "orange" | "blue" | "lavender" | "yellow";
            threshold: number;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        agreement?: {
            feedback: {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            };
            color: "maroon" | "orange" | "blue" | "lavender" | "yellow";
            threshold: number;
        }[] | undefined;
        highlightAgreement: boolean;
    }, {
        agreement?: {
            feedback: {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            };
            color: "maroon" | "orange" | "blue" | "lavender" | "yellow";
            threshold: number;
        }[] | undefined;
        highlightAgreement: boolean;
    }>;
}>, "strip", z.ZodTypeAny, {
    description?: string | undefined;
    subtype: "highlighting";
    view: {
        instruction: string;
        text: string;
        colors: {
            maroon: {
                label?: string | undefined;
                enabled: boolean;
            };
            orange: {
                label?: string | undefined;
                enabled: boolean;
            };
            blue: {
                label?: string | undefined;
                enabled: boolean;
            };
            lavender: {
                label?: string | undefined;
                enabled: boolean;
            };
            yellow: {
                label?: string | undefined;
                enabled: boolean;
            };
        };
    };
    evaluation: {
        mode: "auto" | "skip" | "manual";
        enableRetry: boolean;
        showFeedback: boolean;
        cutoffs: {
            maroon: number;
            orange: number;
            blue: number;
            lavender: number;
            yellow: number;
        };
        highlights: ("maroon" | "orange" | "blue" | "lavender" | "yellow" | null)[];
    };
    feedback: {
        agreement?: {
            feedback: {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            };
            color: "maroon" | "orange" | "blue" | "lavender" | "yellow";
            threshold: number;
        }[] | undefined;
        highlightAgreement: boolean;
    };
    name: string;
}, {
    description?: string | undefined;
    subtype: "highlighting";
    view: {
        instruction: string;
        text: string;
        colors: {
            maroon: {
                label?: string | undefined;
                enabled: boolean;
            };
            orange: {
                label?: string | undefined;
                enabled: boolean;
            };
            blue: {
                label?: string | undefined;
                enabled: boolean;
            };
            lavender: {
                label?: string | undefined;
                enabled: boolean;
            };
            yellow: {
                label?: string | undefined;
                enabled: boolean;
            };
        };
    };
    evaluation: {
        mode: "auto" | "skip" | "manual";
        enableRetry: boolean;
        showFeedback: boolean;
        cutoffs: {
            maroon: number;
            orange: number;
            blue: number;
            lavender: number;
            yellow: number;
        };
        highlights: ("maroon" | "orange" | "blue" | "lavender" | "yellow" | null)[];
    };
    feedback: {
        agreement?: {
            feedback: {
                message: string;
                severity: "error" | "warning" | "info" | "success";
            };
            color: "maroon" | "orange" | "blue" | "lavender" | "yellow";
            threshold: number;
        }[] | undefined;
        highlightAgreement: boolean;
    };
    name: string;
}>;
export declare const StatisticSchema: z.ZodObject<z.extendShape<{
    subtype: z.ZodString;
    count: z.ZodNumber;
}, {
    subtype: z.ZodLiteral<"highlighting">;
    avgAgreement: z.ZodObject<{
        maroon: z.ZodNumber;
        orange: z.ZodNumber;
        blue: z.ZodNumber;
        lavender: z.ZodNumber;
        yellow: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    }, {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    }>;
    highlights: z.ZodObject<{
        maroon: z.ZodArray<z.ZodNumber, "many">;
        orange: z.ZodArray<z.ZodNumber, "many">;
        blue: z.ZodArray<z.ZodNumber, "many">;
        lavender: z.ZodArray<z.ZodNumber, "many">;
        yellow: z.ZodArray<z.ZodNumber, "many">;
    }, "strip", z.ZodTypeAny, {
        maroon: number[];
        orange: number[];
        blue: number[];
        lavender: number[];
        yellow: number[];
    }, {
        maroon: number[];
        orange: number[];
        blue: number[];
        lavender: number[];
        yellow: number[];
    }>;
}>, "strip", z.ZodTypeAny, {
    subtype: "highlighting";
    highlights: {
        maroon: number[];
        orange: number[];
        blue: number[];
        lavender: number[];
        yellow: number[];
    };
    avgAgreement: {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    };
    count: number;
}, {
    subtype: "highlighting";
    highlights: {
        maroon: number[];
        orange: number[];
        blue: number[];
        lavender: number[];
        yellow: number[];
    };
    avgAgreement: {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    };
    count: number;
}>;
export declare const AnswerSchema: z.ZodObject<z.extendShape<{
    subtype: z.ZodString;
}, {
    subtype: z.ZodLiteral<"highlighting">;
    highlights: z.ZodArray<z.ZodUnion<[z.ZodEnum<["maroon", "orange", "blue", "lavender", "yellow"]>, z.ZodNull]>, "many">;
}>, "strip", z.ZodTypeAny, {
    subtype: "highlighting";
    highlights: ("maroon" | "orange" | "blue" | "lavender" | "yellow" | null)[];
}, {
    subtype: "highlighting";
    highlights: ("maroon" | "orange" | "blue" | "lavender" | "yellow" | null)[];
}>;
export declare const ResultSchema: z.ZodObject<z.extendShape<{
    subtype: z.ZodString;
    state: z.ZodEnum<["unknown", "manual", "correct", "wrong"]>;
    allowRetry: z.ZodOptional<z.ZodBoolean>;
    feedback: z.ZodAny;
}, {
    subtype: z.ZodLiteral<"highlighting">;
    agreement: z.ZodObject<{
        maroon: z.ZodNumber;
        orange: z.ZodNumber;
        blue: z.ZodNumber;
        lavender: z.ZodNumber;
        yellow: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    }, {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    }>;
    highlightsFeedback: z.ZodArray<z.ZodUnion<[z.ZodEnum<["correct", "wrong"]>, z.ZodNull]>, "many">;
}>, "strip", z.ZodTypeAny, {
    feedback?: any;
    allowRetry?: boolean | undefined;
    subtype: "highlighting";
    agreement: {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    };
    highlightsFeedback: ("correct" | "wrong" | null)[];
    state: "manual" | "correct" | "wrong" | "unknown";
}, {
    feedback?: any;
    allowRetry?: boolean | undefined;
    subtype: "highlighting";
    agreement: {
        maroon: number;
        orange: number;
        blue: number;
        lavender: number;
        yellow: number;
    };
    highlightsFeedback: ("correct" | "wrong" | null)[];
    state: "manual" | "correct" | "wrong" | "unknown";
}>;
