import { Action as BaseAction, TaskBit as TaskBitBase } from "@bitflow/core";
import { z } from "zod";
import { AnswerSchema, ResultSchema, StatisticSchema, TaskSchema } from "./schemas";
export declare type IHighlightColor = "maroon" | "orange" | "blue" | "lavender" | "yellow";
export declare type ITaskState = {
    highlights: (IHighlightColor | null)[];
    selection?: {
        from: number;
        to: number;
    };
    currentColor?: IHighlightColor;
};
export declare type ITask = z.infer<typeof TaskSchema>;
export declare type IAnswer = z.infer<typeof AnswerSchema>;
export declare type IResult = z.infer<typeof ResultSchema>;
export declare type IStatistic = z.infer<typeof StatisticSchema>;
export interface IInitTextAction extends BaseAction {
    type: "init-text";
    payload: {
        text: string;
    };
}
export interface ISelectAction extends BaseAction {
    type: "select";
    payload: {
        from: number;
        to: number;
    };
}
export interface IHighlightAction extends BaseAction {
    type: "highlight";
    payload: {
        color: IHighlightColor;
    };
}
export interface IEraseAction extends BaseAction {
    type: "erase";
}
export interface IResetAction extends BaseAction {
    type: "reset";
}
export interface IAnswerAction extends BaseAction {
    type: "answer";
    payload: {
        answer: IAnswer;
    };
}
export declare type IAction = IInitTextAction | ISelectAction | IHighlightAction | IEraseAction | IResetAction | IAnswerAction;
export declare type TaskBit = TaskBitBase<ITask, IAnswer, IResult, IStatistic, IAction>;
